@@ -32,12 +32,17 @@ import Plugins.CommandReader
 import Plugins.StdinReader
 import Plugins.XMonadLog
 import Plugins.EWMH
+import Plugins.Kbd
 
 #ifdef INOTIFY
 import Plugins.Mail
 import Plugins.MBox
 #endif
 
+#ifdef DATEZONE
+import Plugins.DateZone
+#endif
+
 -- $config
 -- Configuration data type and default configuration
 
@@ -108,9 +113,12 @@ infixr :*:
 -- the 'Runnable.Runnable' Read instance. To install a plugin just add
 -- the plugin's type to the list of types (separated by ':*:') appearing in
 -- this function's type signature.
-runnableTypes :: Command :*: Monitors :*: Date :*: PipeReader :*: CommandReader :*: StdinReader :*: XMonadLog :*: EWMH :*:
+runnableTypes :: Command :*: Monitors :*: Date :*: PipeReader :*: CommandReader :*: StdinReader :*: XMonadLog :*: EWMH :*: Kbd :*:
 #ifdef INOTIFY
                  Mail :*: MBox :*:
+#endif
+#ifdef DATEZONE
+                 DateZone :*:
 #endif
                  ()
 runnableTypes = undefined
