@@ -27,6 +27,7 @@ import Plugins.Monitors.Swap
 import Plugins.Monitors.Cpu
 import Plugins.Monitors.MultiCpu
 import Plugins.Monitors.Batt
+import Plugins.Monitors.Bright
 import Plugins.Monitors.Thermal
 import Plugins.Monitors.ThermalZone
 import Plugins.Monitors.CpuFreq
@@ -56,6 +57,7 @@ data Monitors = Weather      Station    Args Rate
               | Cpu          Args       Rate
               | MultiCpu     Args       Rate
               | Battery      Args       Rate
+              | Brightness   Args       Rate
               | CpuFreq      Args       Rate
               | CoreTemp     Args       Rate
               | TopProc      Args       Rate
@@ -93,6 +95,7 @@ instance Exec Monitors where
     alias (MultiCpu _ _) = "multicpu"
     alias (Battery _ _) = "battery"
     alias (BatteryP _ _ _)= "battery"
+    alias (Brightness _ _) = "bright"
     alias (CpuFreq _ _) = "cpufreq"
     alias (TopProc _ _) = "top"
     alias (TopMem _ _) = "topmem"
@@ -122,6 +125,7 @@ instance Exec Monitors where
     start (Swap a r) = runM a swapConfig runSwap r
     start (Battery a r) = runM a battConfig runBatt r
     start (BatteryP s a r) = runM a battConfig (runBatt' s) r
+    start (Brightness a r) = runM a brightConfig runBright r
     start (CpuFreq a r) = runM a cpuFreqConfig runCpuFreq r
     start (CoreTemp a r) = runM a coreTempConfig runCoreTemp r
     start (DiskU s a r) = runM a diskUConfig (runDiskU s) r
