@@ -13,11 +13,14 @@
 --
 -----------------------------------------------------------------------------
 
+{-# LANGUAGE BangPatterns #-}
+
 module Plugins.Monitors.Batt ( battConfig, runBatt, runBatt' ) where
 
-import qualified Data.ByteString.Lazy.Char8 as B
+import Control.Exception (SomeException, handle)
 import Plugins.Monitors.Common
 import System.FilePath ((</>))
+import System.IO (IOMode(ReadMode), hGetLine, withFile)
 import System.Posix.Files (fileExist)
 import System.Console.GetOpt
 
@@ -31,6 +34,7 @@ data BattOpts = BattOpts
   , lowThreshold :: Float
   , highThreshold :: Float
   , onlineFile :: FilePath
+  , chargeFile :: FilePath
   }
 
 defaultOpts :: BattOpts
@@ -44,6 +48,7 @@ defaultOpts = BattOpts
   , lowThreshold = -12
   , highThreshold = -10
   , onlineFile = "AC/online"
+  , chargeFile = "charge_full"
   }
 
 options :: [OptDescr (BattOpts -> BattOpts)]
@@ -57,6 +62,7 @@ options =
   , Option "L" ["lowt"] (ReqArg (\x o -> o { lowThreshold = read x }) "") ""
   , Option "H" ["hight"] (ReqArg (\x o -> o { highThreshold = read x }) "") ""
   , Option "f" ["online"] (ReqArg (\x o -> o { onlineFile = x }) "") ""
+  , Option "c" ["charge"] (ReqArg (\x o -> o { chargeFile = x }) "") ""
   ]
 
 parseOpts :: [String] -> IO BattOpts
@@ -83,35 +89,36 @@ data Files = Files
   } | NoFiles
 
 data Battery = Battery
-  { full :: Float
-  , now :: Float
-  , voltage :: Float
-  , current :: Float
+  { full :: !Float
+  , now :: !Float
+  , voltage :: !Float
+  , current :: !Float
   }
 
-batteryFiles :: String -> IO Files
-batteryFiles bat =
-  do is_charge <- fileExist $ prefix </> "charge_now"
-     is_energy <- fileExist $ prefix </> "energy_now"
-     is_current <- fileExist $ prefix </> "current_now"
+safeFileExist :: String -> IO Bool
+safeFileExist f = handle noErrors $ fileExist f
+  where noErrors = const (return False) :: SomeException -> IO Bool
+
+batteryFiles :: String -> String -> IO Files
+batteryFiles charge_file bat =
+  do is_charge <- safeFileExist $ prefix </> "charge_now"
+     is_energy <- safeFileExist $ prefix </> "energy_now"
+     is_current <- safeFileExist $ prefix </> "current_now"
      let cf = if is_current then "current_now" else "power_now"
      return $ case (is_charge, is_energy) of
        (True, _) -> files "charge" cf
        (_, True) -> files "energy" cf
        _ -> NoFiles
   where prefix = sysDir </> bat
-        files ch cf = Files { fFull = prefix </> ch ++ "_full"
+        files ch cf = Files { fFull = prefix </> charge_file
                             , fNow = prefix </> ch ++ "_now"
                             , fCurrent = prefix </> cf
                             , fVoltage = prefix </> "voltage_now" }
 
 haveAc :: FilePath -> IO Bool
-haveAc f = do
-  exists <- fileExist ofile
-  if exists
-    then fmap ((== "1\n") . B.unpack) (B.readFile ofile)
-    else return False
-  where ofile = sysDir </> f
+haveAc f =
+  handle onError $ withFile (sysDir </> f) ReadMode (fmap (== "1") . hGetLine)
+  where onError = const (return False) :: SomeException -> IO Bool
 
 readBattery :: Files -> IO Battery
 readBattery NoFiles = return $ Battery 0 0 0 0
@@ -123,18 +130,21 @@ readBattery files =
        return $ Battery (3600 * a / 1000000) -- wattseconds
                         (3600 * b / 1000000) -- wattseconds
                         (c / 1000000) -- volts
-                        (d / c) -- amperes
-    where grab = fmap (read . B.unpack) . B.readFile
+                        (if c > 0 then (d / c) else -1) -- amperes
+    where grab f = handle onError $ withFile f ReadMode (fmap read . hGetLine)
+          onError = const (return (-1)) :: SomeException -> IO Float
 
 readBatteries :: BattOpts -> [Files] -> IO Result
 readBatteries opts bfs =
     do bats <- mapM readBattery (take 3 bfs)
        ac <- haveAc (onlineFile opts)
        let sign = if ac then 1 else -1
-           left = sum (map now bats) / sum (map full bats)
+           ft = sum (map full bats)
+           left = if ft > 0 then sum (map now bats) / ft else 0
            watts = sign * sum (map voltage bats) * sum (map current bats)
            time = if watts == 0 then 0 else sum $ map time' bats
-           time' b = (if ac then full b - now b else now b) / (sign * watts)
+           mwatts = if watts == 0 then 1 else sign * watts
+           time' b = (if ac then full b - now b else now b) / mwatts
            acstr = if ac then onString opts else offString opts
        return $ if isNaN left then NA else Result left watts time acstr
 
@@ -144,26 +154,26 @@ runBatt = runBatt' ["BAT0","BAT1","BAT2"]
 runBatt' :: [String] -> [String] -> Monitor String
 runBatt' bfs args = do
   opts <- io $ parseOpts args
-  c <- io $ readBatteries opts =<< mapM batteryFiles bfs
+  c <- io $ readBatteries opts =<< mapM (batteryFiles (chargeFile opts)) bfs
   case c of
     Result x w t s ->
       do l <- fmtPercent x
          parseTemplate (l ++ s:[fmtTime $ floor t, fmtWatts w opts])
     NA -> return "N/A"
- where fmtPercent :: Float -> Monitor [String]
-       fmtPercent x = do
-         p <- showPercentWithColors x
-         b <- showPercentBar (100 * x) x
-         return [b, p]
-       fmtWatts x o = color x o $ showDigits 1 x ++ "W"
-       fmtTime :: Integer -> String
-       fmtTime x = hours ++ ":" ++ if length minutes == 2
-                                   then minutes else '0' : minutes
-         where hours = show (x `div` 3600)
-               minutes = show ((x `mod` 3600) `div` 60)
-       maybeColor Nothing _ = ""
-       maybeColor (Just c) str = "<fc=" ++ c ++ ">" ++ str ++ "</fc>"
-       color x o | x >= 0 = maybeColor (posColor o)
-                 | x >= highThreshold o = maybeColor (highWColor o)
-                 | x >= lowThreshold o = maybeColor (mediumWColor o)
-                 | otherwise = maybeColor (lowWColor o)
+  where fmtPercent :: Float -> Monitor [String]
+        fmtPercent x = do
+          p <- showPercentWithColors x
+          b <- showPercentBar (100 * x) x
+          return [b, p]
+        fmtWatts x o = color x o $ showDigits 1 x ++ "W"
+        fmtTime :: Integer -> String
+        fmtTime x = hours ++ ":" ++ if length minutes == 2
+                                    then minutes else '0' : minutes
+          where hours = show (x `div` 3600)
+                minutes = show ((x `mod` 3600) `div` 60)
+        maybeColor Nothing _ = ""
+        maybeColor (Just c) str = "<fc=" ++ c ++ ">" ++ str ++ "</fc>"
+        color x o | x >= 0 = maybeColor (posColor o)
+                  | x >= highThreshold o = maybeColor (highWColor o)
+                  | x >= lowThreshold o = maybeColor (mediumWColor o)
+                  | otherwise = maybeColor (lowWColor o)
